Struct amazon_sp_aplus_content::models::standard_single_side_image_module::StandardSingleSideImageModule
source · [−]pub struct StandardSingleSideImageModule {
pub image_position_type: PositionType,
pub block: Option<Box<StandardImageTextBlock>>,
}Expand description
StandardSingleSideImageModule : A standard headline and body text with an image on the side.
Fields
image_position_type: PositionTypeblock: Option<Box<StandardImageTextBlock>>Implementations
sourceimpl StandardSingleSideImageModule
impl StandardSingleSideImageModule
sourcepub fn new(image_position_type: PositionType) -> StandardSingleSideImageModule
pub fn new(image_position_type: PositionType) -> StandardSingleSideImageModule
A standard headline and body text with an image on the side.